@@ -6,6 +6,7 @@ import os
 import shutil
 import tempfile
 import typing
+from fp.fp import FreeProxy
 from datetime import date
 from typing import Any, Optional, Union
 
@@ -36,20 +37,24 @@ class Client:
     ) -> Union[list[Any], dict[Any, Any], str]:
 
         headers.update(self.DEFAULT_HEADERS)
+        counter_tries = 0
 
         while True:
             try:
-                response: Response = requests.request(method, f"{self.BASE_URL}{end_point}", params=params, headers=headers, timeout=timeout)
-            except Exception:
+                counter_tries += 1
+                response: Response = requests.request(method, f"{self.BASE_URL}{end_point}", params=params, headers=headers, timeout=timeout, proxies={"http": self.__proxy})
+
+                if not response.ok:
+                    self.__proxy = FreeProxy().get()
+                    print(f"Connection error: {response.status_code} try: {counter_tries}", end="\r")
+                    continue
+            except Exception as e:
+                print(e)
+                self.__proxy = FreeProxy().get()
                 continue
             else:
                 break
 
-        if not response.ok:
-            if self.debug:
-                print(f"Connection error: {response.status_code}")
-            return self.request(method, end_point, headers, params, timeout, json_, debug_key)
-
         if json_:
             try:
                 response_json: Union[list[Any], dict[Any, Any]] = response.json()
@@ -113,6 +118,7 @@ class Client:
         self.debug = debug
         self.debug_fn = debug_fn
         self.debug_value = debug_value
+        self.__proxy = FreeProxy().get()
 
     class Categories:
         def __init__(self, client: Client) -> None:
@@ -191,6 +197,7 @@ class Client:
                 max_size = 30
 
                 while True:
+                    print(f"{page}/{total_pages}", end="\r")
                     if self.data.get(category.id) is None:
                         self.data[category.id] = {}
 
